@@ -139,7 +139,7 @@ class MVForecaster:
         for key, value in kwargs.items():
             setattr(self, key, value)
 
-        if names is not None:
+        if names is not None: # checking for these objects is how we know whether user supplied names later
             names = list(names)
             globals()['name_series_map'] = {names[i]:[f'series{i+1}',f'y{i+1}'] for i in range(self.n_series)}
             globals()['y_name_map'] = {f'y{i+1}':names[i] for i in range(self.n_series)}
@@ -152,6 +152,7 @@ class MVForecaster:
     Freq={}
     N_actuals={}
     N_series={}
+    SeriesNames={}
     ForecastLength={}
     Xvars={}
     TestLength={}
@@ -167,6 +168,9 @@ class MVForecaster:
             self.freq,
             len(self.current_dates),
             self.n_series,
+            [f'series{i+1}' for i in range(self.n_series)] 
+            if 'name_series_map' not in globals() 
+            else list(name_series_map.keys()),
             len(self.future_dates),
             list(self.current_xreg.keys()),
             self.test_length,
@@ -565,18 +569,20 @@ class MVForecaster:
         lags=1,
         **kwargs):
         """ runs the vector multi-variate forecast start-to-finish. all Xvars used always. all sklearn estimators supported.
+        see example: https://scalecast-examples.readthedocs.io/en/latest/multivariate/multivariate.html
 
         Args:
-            fcster (str): one of _sklearn_estimators_.
+            fcster (str): one of _sklearn_estimators_. reads the estimator set to `set_estimator()` method.
             dynamic_testing (bool):
                 whether to dynamically test the forecast (meaning AR terms will be propogated with predicted values).
                 setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
                 when False, test-set metrics effectively become an average of one-step forecasts.
             tune (bool): default False.
                 whether the model is being tuned.
-            normalizer (str): one of _normalizer_.
+                does not need to be specified by user.
+            normalizer (str): one of _normalizer_. default 'minmax'.
                 if not None, normalizer applied to training data only to not leak.
-            lags (int, list[int], dict[str,int|list[int]]): default 1.
+            lags (int | list[int] | dict[str,int | list[int]]): default 1.
                 the lags to add from each series to forecast with.
                 needs to use at least one lag (otherwise, use a univariate approach).
                 if int, that many lags will be added for all series
@@ -985,7 +991,7 @@ class MVForecaster:
         k = 0
         for i, s in enumerate(series):
             sns.lineplot(x=self.current_dates.to_list(),
-                y=getattr(self,'series{}'.format(s.split('y')[-1])).to_list() if not level else getattr(self,f'series{i+1}')['levely'][-len(self.current_dates):],
+                y=getattr(self,'series{}'.format(s.split('y')[-1]))['y'].to_list() if not level else getattr(self,f'series{i+1}')['levely'][-len(self.current_dates):],
                 label = f'{labels[i]} actual',
                 ax=ax,
                 color = _series_colors_[i])
@@ -1204,10 +1210,12 @@ class MVForecaster:
                     elif c == "LastTestSetActual":
                         model_summary_sm[c] = [self.history[m]["TestSetActuals"][s][-1]]
                     elif c == "OptimizedOn" and hasattr(self,'best_model'): 
-                        if 'series_name_map' in globals():
-                            model_summary_sm['OptimizedOn'] = series_name_map[self.optimize_on]
+                        if self.optimize_on == 'mean':
+                            model_summary_sm['OptimizedOn'] = ['mean']
+                        elif 'series_name_map' in globals():
+                            model_summary_sm['OptimizedOn'] = [series_name_map[self.optimize_on]]
                         else:
-                            model_summary_sm['OptimizedOn'] = self.optimize_on
+                            model_summary_sm['OptimizedOn'] = [self.optimize_on]
                         if hasattr(self,'optimize_metric'):
                             model_summary_sm['MetricOptimized'] = self.optimize_metric
                         model_summary_sm["best_model"] = m == self.best_model
